##
##  gnuplot.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gnuplot
Summary:      Plotting System
URL:          http://www.gnuplot.info/
Vendor:       Thomas Williams, Colin Kelley
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Diagram
License:      GPL
Version:      5.4.8
Release:      20230611

#   list of sources
Source0:      http://downloads.sourceforge.net/gnuplot/gnuplot-%{version}.tar.gz
Patch0:       gnuplot.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, png, zlib, readline, ncurses, texinfo
PreReq:       OpenPKG, openpkg >= 20160101, png, zlib, readline, ncurses

%description
    Gnuplot is a command-driven interactive function plotting program.
    It can be used to plot functions and data points in both two-
    and three-dimensional plots in many different formats, and will
    accommodate many of the needs of today's scientists for graphic data
    representation.

%track
    prog gnuplot = {
        version   = %{version}
        url       = http://sourceforge.net/projects/gnuplot/files/
        regex     = gnuplot-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lz" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --with-readline=%{l_prefix} \
        --with-png=%{l_prefix} \
        --with-gd=%{l_prefix} \
        --without-pdf \
        --without-x
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

